#[non_exhaustive]pub enum RefundRequestError {
EmptyPaymentId,
Amount(MoneyError),
}Expand description
A RefundRequest was built out of parts that do not make a valid refund.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
EmptyPaymentId
The payment identifier was empty.
Amount(MoneyError)
The amount was not one that can be refunded.